% view_frame.m
% Austin Nicolai
% 10/7/16
%
% purpose:
%
%   visualizes a single frame of processed sonar data. checks for
%   appropriate display scaling and allows for the display colormap
%   to be selected.
%
%   only tested for use with the output of process_csv.m.
%
% outputs:
%
%   None
%
% inputs:
%
%   img:     array of all processed sonar frames.
%   frame:   the frame number to display.
%   cmap:    the colormap to use.
%   fig_num: the figure number to display in.

function view_frame(img, frame, cmap, fig_num)

% get image size
img_h = size(img, 1);
img_w = size(img, 2);

% reshape to 2D for display
img_view = img(:, :, frame);
img_view = reshape(img_view, [img_h, img_w]);

% display, flipping upside down to account for imshow()
figure(fig_num);
if isa(img_view, 'float') && (max(max(img_view)) >= 1)
    imshow(flipud(img_view/256), 'ColorMap', colormap(cmap)); % scale to [0,1] since float
else
    imshow(flipud(img_view), 'ColorMap', colormap(cmap));
end

end
